@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: project.c 3570 2009-02-10 21:10:50Z eht16 $
+ * $Id: project.c 3814 2009-05-26 19:49:18Z eht16 $
  */
 
 /** @file project.h
@@ -48,6 +48,7 @@
 #include "interface.h"
 #include "editor.h"
 #include "stash.h"
+#include "treeviews.h"
 
 
 ProjectPrefs project_prefs = { NULL, FALSE, FALSE };
@@ -84,7 +85,6 @@ typedef struct _PropertyDialogElements
 static gboolean update_config(const PropertyDialogElements *e);
 static void on_file_save_button_clicked(GtkButton *button, PropertyDialogElements *e);
 static void on_file_open_button_clicked(GtkButton *button, PropertyDialogElements *e);
-static gboolean close_open_project(void);
 static gboolean load_config(const gchar *filename);
 static gboolean write_config(gboolean emit_signal);
 static void on_name_entry_changed(GtkEditable *editable, PropertyDialogElements *e);
@@ -99,7 +99,7 @@ static void on_entries_changed(GtkEditable *editable, PropertyDialogElements *e)
 #define PROJECT_DIR _("projects")
 
 
-void project_new()
+void project_new(void)
 {
 	GtkWidget *vbox;
 	GtkWidget *table;
@@ -110,7 +110,7 @@ void project_new()
 	PropertyDialogElements *e;
 	gint response;
 
-	if (! close_open_project()) return;
+	if (! project_ask_close()) return;
 
 	g_return_if_fail(app->project == NULL);
 
@@ -191,14 +191,34 @@ void project_new()
 	retry:
 	response = gtk_dialog_run(GTK_DIALOG(e->dialog));
 	if (response == GTK_RESPONSE_OK)
+	{
 		if (! update_config(e))
 			goto retry;
+		else
+			ui_add_recent_project_file(app->project->file_name);
+	}
 
 	gtk_widget_destroy(e->dialog);
 	g_free(e);
 }
 
 
+gboolean project_load_file_with_session(const gchar *locale_file_name)
+{
+	if (project_load_file(locale_file_name))
+	{
+		if (project_prefs.project_session)
+		{
+			configuration_open_files();
+			/* open a new file if no other file was opened */
+			document_new_file_if_non_open();
+		}
+		return TRUE;
+	}
+	return FALSE;
+}
+
+
 #ifndef G_OS_WIN32
 static void run_open_dialog(GtkDialog *dialog)
 {
@@ -212,7 +232,7 @@ static void run_open_dialog(GtkDialog *dialog)
 		gchar *filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
 
 		/* try to load the config */
-		if (! project_load_file(filename))
+		if (! project_load_file_with_session(filename))
 		{
 			gchar *utf8_filename = utils_get_utf8_from_locale(filename);
 
@@ -223,18 +243,12 @@ static void run_open_dialog(GtkDialog *dialog)
 			goto retry;
 		}
 		g_free(filename);
-		if (project_prefs.project_session)
-		{
-			configuration_open_files();
-			/* open a new file if no other file was opened */
-			document_new_file_if_non_open();
-		}
 	}
 }
 #endif
 
 
-void project_open()
+void project_open(void)
 {
 	const gchar *dir = local_prefs.project_file_path;
 #ifdef G_OS_WIN32
@@ -244,23 +258,17 @@ void project_open()
 	GtkFileFilter *filter;
 	gchar *locale_path;
 #endif
-	if (! close_open_project()) return;
+	if (! project_ask_close()) return;
 
 #ifdef G_OS_WIN32
 	file = win32_show_project_open_dialog(main_widgets.window, _("Open Project"), dir, FALSE, TRUE);
 	if (file != NULL)
 	{
 		/* try to load the config */
-		if (! project_load_file(file))
+		if (! project_load_file_with_session(file))
 		{
 			SHOW_ERR1(_("Project file \"%s\" could not be loaded."), file);
 		}
-		else if (project_prefs.project_session)
-		{
-			configuration_open_files();
-			/* open a new file if no other file was opened */
-			document_new_file_if_non_open();
-		}
 		g_free(file);
 	}
 #else
@@ -310,6 +318,7 @@ static void update_ui(void)
 {
 	ui_set_window_title(NULL);
 	build_menu_update(NULL);
+	treeviews_openfiles_update_all();
 }
 
 
@@ -338,7 +347,7 @@ void project_close(gboolean open_default)
 		document_close_all();
 
 		/* after closing all tabs let's open the tabs found in the default config */
-		if (open_default == TRUE && cl_options.load_session)
+		if (open_default && cl_options.load_session)
 		{
 			configuration_reload_default_session();
 			configuration_open_files();
@@ -453,7 +462,7 @@ static void create_properties_dialog(PropertyDialogElements *e)
 		"Options can be appended to the command. "
 		"Leave blank to use the default run command."));
 	button = gtk_button_new();
-	g_signal_connect(button, "clicked", G_CALLBACK(on_file_open_button_clicked), e->run_cmd);
+	g_signal_connect(button, "clicked", G_CALLBACK(on_file_open_button_clicked), e);
 	image = gtk_image_new_from_stock("gtk-open", GTK_ICON_SIZE_BUTTON);
 	gtk_container_add(GTK_CONTAINER(button), image);
 	bbox = gtk_hbox_new(FALSE, 6);
@@ -490,7 +499,7 @@ static void create_properties_dialog(PropertyDialogElements *e)
 }
 
 
-void project_properties()
+void project_properties(void)
 {
 	PropertyDialogElements *e = g_new(PropertyDialogElements, 1);
 	GeanyProject *p = app->project;
@@ -561,7 +570,7 @@ void project_properties()
 /* checks whether there is an already open project and asks the user if he wants to close it or
  * abort the current action. Returns FALSE when the current action(the caller) should be cancelled
  * and TRUE if we can go ahead */
-static gboolean close_open_project()
+gboolean project_ask_close(void)
 {
 	if (app->project != NULL)
 	{
@@ -893,7 +902,12 @@ gboolean project_load_file(const gchar *locale_file_name)
 
 	if (load_config(locale_file_name))
 	{
+		gchar *utf8_filename = utils_get_utf8_from_locale(locale_file_name);
+
 		ui_set_statusbar(TRUE, _("Project \"%s\" opened."), app->project->name);
+
+		ui_add_recent_project_file(utf8_filename);
+		g_free(utf8_filename);
 		return TRUE;
 	}
 	else
@@ -945,7 +959,7 @@ static gboolean load_config(const gchar *filename)
 		/* now close all open files */
 		document_close_all();
 		/* read session files so they can be opened with configuration_open_files() */
-		configuration_load_session_files(config);
+		configuration_load_session_files(config, FALSE);
 	}
 	g_signal_emit_by_name(geany_object, "project-open", config);
 	g_key_file_free(config);
@@ -1016,7 +1030,7 @@ static gboolean write_config(gboolean emit_signal)
  * base path if it is absolute or it is built out of project file name's dir and base_path.
  * If there is no project or project's base_path is invalid, NULL will be returned.
  * The returned string should be freed when no longer needed. */
-gchar *project_get_base_path()
+gchar *project_get_base_path(void)
 {
 	GeanyProject *project = app->project;
 
@@ -1029,7 +1043,10 @@ gchar *project_get_base_path()
 			gchar *path;
 			gchar *dir = g_path_get_dirname(project->file_name);
 
-			path = g_strconcat(dir, G_DIR_SEPARATOR_S, project->base_path, NULL);
+			if (utils_str_equal(project->base_path, "./"))
+				return dir;
+			else
+				path = g_strconcat(dir, G_DIR_SEPARATOR_S, project->base_path, NULL);
 			g_free(dir);
 			return path;
 		}
@@ -1040,7 +1057,7 @@ gchar *project_get_base_path()
 
 /* Returns: NULL if the default path should be used, or a UTF-8 path.
  * Maybe in future this will support a separate project make path from base path. */
-gchar *project_get_make_dir()
+gchar *project_get_make_dir(void)
 {
 	GeanyProject *project = app->project;
 
@@ -1086,20 +1103,26 @@ void project_load_prefs(GKeyFile *config)
 
 
 /* Initialize project-related preferences in the Preferences dialog. */
-void project_setup_prefs()
+void project_setup_prefs(void)
 {
 	GtkWidget *path_entry = ui_lookup_widget(ui_widgets.prefs_dialog, "project_file_path_entry");
 	GtkWidget *path_btn = ui_lookup_widget(ui_widgets.prefs_dialog, "project_file_path_button");
+	static gboolean callback_setup = FALSE;
 
 	g_return_if_fail(local_prefs.project_file_path != NULL);
+	
 	gtk_entry_set_text(GTK_ENTRY(path_entry), local_prefs.project_file_path);
-	ui_setup_open_button_callback(path_btn, NULL,
-		GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, GTK_ENTRY(path_entry));
+	if (! callback_setup)
+	{	/* connect the callback only once */
+		callback_setup = TRUE;
+		ui_setup_open_button_callback(path_btn, NULL,
+			GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, GTK_ENTRY(path_entry));
+	}
 }
 
 
 /* Update project-related preferences after using the Preferences dialog. */
-void project_apply_prefs()
+void project_apply_prefs(void)
 {
 	GtkWidget *path_entry = ui_lookup_widget(ui_widgets.prefs_dialog, "project_file_path_entry");
 	const gchar *str;
